==> v1.6.8.zip: session-desktop/ts/test/session/unit/selectors/conversations_test.ts <==
import { assert } from 'chai';
import {
  ConversationNotificationSetting,
  ConversationTypeEnum,
} from '../../../../models/conversation';

import { ConversationLookupType } from '../../../../state/ducks/conversations';
import {
  _getConversationComparator,
  _getLeftPaneLists,
} from '../../../../state/selectors/conversations';

describe('state/selectors/conversations', () => {
  describe('#getLeftPaneList', () => {
    // tslint:disable-next-line: max-func-body-length
    it('sorts conversations based on timestamp then by intl-friendly title', () => {
      const i18n = (key: string) => key;
      const data: ConversationLookupType = {
        id1: {
          id: 'id1',
          activeAt: 0,
          name: 'No timestamp',
          phoneNumber: 'notused',

          type: ConversationTypeEnum.PRIVATE,
          isMe: false,
          unreadCount: 1,
          mentionedUs: false,
          isSelected: false,
          isTyping: false,
          isBlocked: false,
          isKickedFromGroup: false,
          left: false,
          hasNickname: false,
          isPublic: false,
          subscriberCount: 0,
          currentNotificationSetting: 'all',
          weAreAdmin: false,
          isGroup: false,
          isPrivate: false,
          notificationForConvo: [{ value: 'all', name: 'all' }],
          avatarPath: '',
          groupAdmins: [],
          lastMessage: undefined,
          members: [],
          profileName: 'df',
          expireTimer: 0,
          isPinned: false,
        },
        id2: {
          id: 'id2',
          activeAt: 20,
          name: 'B',
          phoneNumber: 'notused',

          type: ConversationTypeEnum.PRIVATE,
          isMe: false,
          unreadCount: 1,
          mentionedUs: false,
          isSelected: false,
          isTyping: false,
          isBlocked: false,
          isKickedFromGroup: false,
          left: false,
          hasNickname: false,
          isPublic: false,
          subscriberCount: 0,
          currentNotificationSetting: 'all',
          weAreAdmin: false,
          isGroup: false,
          isPrivate: false,
          notificationForConvo: [{ value: 'all', name: 'all' }],
          avatarPath: '',
          groupAdmins: [],
          lastMessage: undefined,
          members: [],
          profileName: 'df',
          expireTimer: 0,
          isPinned: false,
        },
        id3: {
          id: 'id3',
          activeAt: 20,
          name: 'C',
          phoneNumber: 'notused',
          type: ConversationTypeEnum.PRIVATE,
          isMe: false,
          unreadCount: 1,
          mentionedUs: false,
          isSelected: false,
          isTyping: false,
          isBlocked: false,
          isKickedFromGroup: false,
          left: false,
          hasNickname: false,
          isPublic: false,
          subscriberCount: 0,
          currentNotificationSetting: 'all',
          weAreAdmin: false,
          isGroup: false,
          isPrivate: false,
          notificationForConvo: [{ value: 'all', name: 'all' }],
          avatarPath: '',
          groupAdmins: [],
          lastMessage: undefined,
          members: [],
          profileName: 'df',
          expireTimer: 0,
          isPinned: false,
        },
        id4: {
          id: 'id4',
          activeAt: 20,
          name: 'Á',
          phoneNumber: 'notused',
          type: ConversationTypeEnum.PRIVATE,
          isMe: false,
          unreadCount: 1,
          mentionedUs: false,
          isSelected: false,
          isTyping: false,
          isBlocked: false,
          isKickedFromGroup: false,
          left: false,
          hasNickname: false,
          isPublic: false,
          subscriberCount: 0,
          currentNotificationSetting: 'all',
          weAreAdmin: false,
          isGroup: false,
          isPrivate: false,
          notificationForConvo: [{ value: 'all', name: 'all' }],
          avatarPath: '',
          groupAdmins: [],
          expireTimer: 0,
          lastMessage: undefined,
          members: [],
          profileName: 'df',
          isPinned: false,
        },
        id5: {
          id: 'id5',
          activeAt: 30,
          name: 'First!',
          phoneNumber: 'notused',
          type: ConversationTypeEnum.PRIVATE,
          isMe: false,
          unreadCount: 1,
          mentionedUs: false,
          isSelected: false,
          isTyping: false,
          isBlocked: false,
          isKickedFromGroup: false,
          left: false,
          hasNickname: false,
          isPublic: false,
          subscriberCount: 0,
          expireTimer: 0,
          currentNotificationSetting: 'all',
          weAreAdmin: false,
          isGroup: false,
          isPrivate: false,
          notificationForConvo: [{ value: 'all', name: 'all' }],
          avatarPath: '',
          groupAdmins: [],
          lastMessage: undefined,
          members: [],
          profileName: 'df',
          isPinned: false,
        },
      };
      const comparator = _getConversationComparator(i18n);
      const { conversations } = _getLeftPaneLists(data, comparator);

      assert.strictEqual(conversations[0].name, 'First!');
      assert.strictEqual(conversations[1].name, 'Á');
      assert.strictEqual(conversations[2].name, 'B');
      assert.strictEqual(conversations[3].name, 'C');
    });
  });

  describe('#getLeftPaneListWithPinned', () => {
    // tslint:disable-next-line: max-func-body-length
    it('sorts conversations based on pin, timestamp then by intl-friendly title', () => {
      const i18n = (key: string) => key;
      const data: ConversationLookupType = {
        id1: {
          id: 'id1',
          activeAt: 0,
          name: 'No timestamp',
          phoneNumber: 'notused',

          type: ConversationTypeEnum.PRIVATE,
          isMe: false,
          unreadCount: 1,
          mentionedUs: false,
          isSelected: false,
          isTyping: false,
          isBlocked: false,
          isKickedFromGroup: false,
          left: false,
          subscriberCount: 0,
          expireTimer: 0,
          currentNotificationSetting: 'all',
          weAreAdmin: false,
          isGroup: false,
          isPrivate: false,
          notificationForConvo: [{ value: 'all', name: 'all' }],
          avatarPath: '',
          groupAdmins: [],
          lastMessage: undefined,
          members: [],
          profileName: 'df',
          isPinned: false,
          hasNickname: false,
          isPublic: false,
        },
        id2: {
          id: 'id2',
          activeAt: 20,
          name: 'B',
          phoneNumber: 'notused',

          type: ConversationTypeEnum.PRIVATE,
          isMe: false,
          unreadCount: 1,
          mentionedUs: false,
          isSelected: false,
          isTyping: false,
          isBlocked: false,
          isKickedFromGroup: false,
          left: false,
          subscriberCount: 0,
          expireTimer: 0,
          currentNotificationSetting: 'all',
          weAreAdmin: false,
          isGroup: false,
          isPrivate: false,
          notificationForConvo: [{ value: 'all', name: 'all' }],
          avatarPath: '',
          groupAdmins: [],
          lastMessage: undefined,
          members: [],
          profileName: 'df',
          isPinned: false,
          hasNickname: false,
          isPublic: false,
        },
        id3: {
          id: 'id3',
          activeAt: 20,
          name: 'C',
          phoneNumber: 'notused',

          type: ConversationTypeEnum.PRIVATE,
          isMe: false,
          unreadCount: 1,
          mentionedUs: false,
          isSelected: false,
          isTyping: false,
          isBlocked: false,
          isKickedFromGroup: false,
          left: false,
          subscriberCount: 0,
          expireTimer: 0,
          currentNotificationSetting: 'all',
          weAreAdmin: false,
          isGroup: false,
          isPrivate: false,
          notificationForConvo: [{ value: 'all', name: 'all' }],
          avatarPath: '',
          groupAdmins: [],
          lastMessage: undefined,
          members: [],
          profileName: 'df',
          isPinned: true,
          hasNickname: false,
          isPublic: false,
        },
        id4: {
          id: 'id4',
          activeAt: 20,
          name: 'Á',
          phoneNumber: 'notused',
          type: ConversationTypeEnum.PRIVATE,
          isMe: false,
          unreadCount: 1,
          mentionedUs: false,
          isSelected: false,
          isTyping: false,
          isBlocked: false,
          isKickedFromGroup: false,
          left: false,
          subscriberCount: 0,
          expireTimer: 0,
          currentNotificationSetting: 'all',
          weAreAdmin: false,
          isGroup: false,
          isPrivate: false,
          notificationForConvo: [{ value: 'all', name: 'all' }],
          avatarPath: '',
          groupAdmins: [],
          lastMessage: undefined,
          members: [],
          profileName: 'df',
          isPinned: true,
          hasNickname: false,
          isPublic: false,
        },
        id5: {
          id: 'id5',
          activeAt: 30,
          name: 'First!',
          phoneNumber: 'notused',
          type: ConversationTypeEnum.PRIVATE,
          isMe: false,
          unreadCount: 1,
          mentionedUs: false,
          isSelected: false,
          isTyping: false,
          isBlocked: false,
          isKickedFromGroup: false,
          left: false,

          subscriberCount: 0,
          expireTimer: 0,
          currentNotificationSetting: 'all',
          weAreAdmin: false,
          isGroup: false,
          isPrivate: false,
          notificationForConvo: [{ value: 'all', name: 'all' }],
          avatarPath: '',
          groupAdmins: [],
          lastMessage: undefined,
          members: [],
          profileName: 'df',
          isPinned: false,
          hasNickname: false,
          isPublic: false,
        },
      };
      const comparator = _getConversationComparator(i18n);
      const { conversations } = _getLeftPaneLists(data, comparator);

      assert.strictEqual(conversations[0].name, 'Á');
      assert.strictEqual(conversations[1].name, 'C');
      assert.strictEqual(conversations[2].name, 'First!');
      assert.strictEqual(conversations[3].name, 'B');
    });
  });
});

==> v1.11.0.zip: session-desktop/ts/test/session/unit/selectors/conversations_test.ts <==
import { assert } from 'chai';
import {
  CONVERSATION_PRIORITIES,
  ConversationTypeEnum,
} from '../../../../models/conversationAttributes';

import { ConversationLookupType } from '../../../../state/ducks/conversations';
import {
  _getConversationComparator,
  _getSortedConversations,
} from '../../../../state/selectors/conversations';

describe('state/selectors/conversations', () => {
  describe('#getSortedConversationsList', () => {
    // tslint:disable-next-line: max-func-body-length
    it('sorts conversations based on timestamp then by intl-friendly title', () => {
      const i18n = (key: string) => key;
      const data: ConversationLookupType = {
        id1: {
          id: 'id1',
          activeAt: 0,
          displayNameInProfile: 'No timestamp',
          type: ConversationTypeEnum.PRIVATE,
          isMe: false,
          unreadCount: 1,
          mentionedUs: false,
          isTyping: false,
          isBlocked: false,
          isKickedFromGroup: false,
          left: false,
          isPublic: false,
          currentNotificationSetting: 'all',
          weAreAdmin: false,
          isPrivate: false,

          avatarPath: '',
          groupAdmins: [],
          lastMessage: undefined,
          members: [],
          expireTimer: 0,
          priority: CONVERSATION_PRIORITIES.default,
        },
        id2: {
          id: 'id2',
          activeAt: 20,
          displayNameInProfile: 'B',
          type: ConversationTypeEnum.PRIVATE,
          isMe: false,
          unreadCount: 1,
          mentionedUs: false,
          isTyping: false,
          isBlocked: false,
          isKickedFromGroup: false,
          left: false,
          isPublic: false,
          currentNotificationSetting: 'all',
          weAreAdmin: false,
          isPrivate: false,
          avatarPath: '',
          groupAdmins: [],
          lastMessage: undefined,
          members: [],
          expireTimer: 0,
          priority: CONVERSATION_PRIORITIES.default,
        },
        id3: {
          id: 'id3',
          activeAt: 20,
          displayNameInProfile: 'C',
          type: ConversationTypeEnum.PRIVATE,
          isMe: false,
          unreadCount: 1,
          mentionedUs: false,
          isTyping: false,
          isBlocked: false,
          isKickedFromGroup: false,
          left: false,
          isPublic: false,
          currentNotificationSetting: 'all',
          weAreAdmin: false,
          isPrivate: false,
          avatarPath: '',
          groupAdmins: [],
          lastMessage: undefined,
          members: [],
          expireTimer: 0,
          priority: CONVERSATION_PRIORITIES.default,
        },
        id4: {
          id: 'id4',
          activeAt: 20,
          displayNameInProfile: 'Á',
          type: ConversationTypeEnum.PRIVATE,
          isMe: false,
          unreadCount: 1,
          mentionedUs: false,
          isTyping: false,
          isBlocked: false,
          isKickedFromGroup: false,
          left: false,
          isPublic: false,
          currentNotificationSetting: 'all',
          weAreAdmin: false,
          isPrivate: false,
          avatarPath: '',
          groupAdmins: [],
          expireTimer: 0,
          lastMessage: undefined,
          members: [],
          priority: CONVERSATION_PRIORITIES.default,
        },
        id5: {
          id: 'id5',
          activeAt: 30,
          displayNameInProfile: 'First!',
          type: ConversationTypeEnum.PRIVATE,
          isMe: false,
          unreadCount: 1,
          mentionedUs: false,
          isTyping: false,
          isBlocked: false,
          isKickedFromGroup: false,
          left: false,
          isPublic: false,
          expireTimer: 0,
          currentNotificationSetting: 'all',
          weAreAdmin: false,
          isPrivate: false,

          avatarPath: '',
          groupAdmins: [],
          lastMessage: undefined,
          members: [],
          priority: CONVERSATION_PRIORITIES.default,
        },
      };
      const comparator = _getConversationComparator(i18n);
      const conversations = _getSortedConversations(data, comparator);

      assert.strictEqual(conversations[0].displayNameInProfile, 'First!');
      assert.strictEqual(conversations[1].displayNameInProfile, 'Á');
      assert.strictEqual(conversations[2].displayNameInProfile, 'B');
      assert.strictEqual(conversations[3].displayNameInProfile, 'C');
    });
  });

  describe('#getSortedConversationsWithPinned', () => {
    // tslint:disable-next-line: max-func-body-length
    it('sorts conversations based on pin, timestamp then by intl-friendly title', () => {
      const i18n = (key: string) => key;
      const data: ConversationLookupType = {
        id1: {
          id: 'id1',
          activeAt: 0,
          displayNameInProfile: 'No timestamp',

          type: ConversationTypeEnum.PRIVATE,
          isMe: false,
          unreadCount: 1,
          mentionedUs: false,
          isTyping: false,
          isBlocked: false,
          isKickedFromGroup: false,
          left: false,
          expireTimer: 0,
          currentNotificationSetting: 'all',
          weAreAdmin: false,
          isPrivate: false,

          avatarPath: '',
          groupAdmins: [],
          lastMessage: undefined,
          members: [],
          priority: CONVERSATION_PRIORITIES.default,
          isPublic: false,
        },
        id2: {
          id: 'id2',
          activeAt: 20,
          displayNameInProfile: 'B',

          type: ConversationTypeEnum.PRIVATE,
          isMe: false,
          unreadCount: 1,
          mentionedUs: false,
          isTyping: false,
          isBlocked: false,
          isKickedFromGroup: false,
          left: false,
          expireTimer: 0,
          currentNotificationSetting: 'all',
          weAreAdmin: false,
          isPrivate: false,

          avatarPath: '',
          groupAdmins: [],
          lastMessage: undefined,
          members: [],

          priority: CONVERSATION_PRIORITIES.default,
          isPublic: false,
        },
        id3: {
          id: 'id3',
          activeAt: 20,

          type: ConversationTypeEnum.PRIVATE,
          isMe: false,
          unreadCount: 1,
          mentionedUs: false,
          isTyping: false,
          isBlocked: false,
          isKickedFromGroup: false,
          left: false,
          expireTimer: 0,
          currentNotificationSetting: 'all',
          weAreAdmin: false,
          isPrivate: false,
          displayNameInProfile: 'C',

          avatarPath: '',
          groupAdmins: [],
          lastMessage: undefined,
          members: [],
          priority: CONVERSATION_PRIORITIES.pinned,
          isPublic: false,
        },
        id4: {
          id: 'id4',
          activeAt: 20,
          displayNameInProfile: 'Á',
          type: ConversationTypeEnum.PRIVATE,
          isMe: false,
          unreadCount: 1,
          mentionedUs: false,
          isTyping: false,
          isBlocked: false,
          isKickedFromGroup: false,
          left: false,
          expireTimer: 0,
          currentNotificationSetting: 'all',
          weAreAdmin: false,
          isPrivate: false,

          avatarPath: '',
          groupAdmins: [],
          lastMessage: undefined,
          members: [],
          priority: CONVERSATION_PRIORITIES.pinned,
          isPublic: false,
        },
        id5: {
          id: 'id5',
          activeAt: 30,
          displayNameInProfile: 'First!',
          type: ConversationTypeEnum.PRIVATE,
          isMe: false,
          unreadCount: 1,
          mentionedUs: false,
          isTyping: false,
          isBlocked: false,
          isKickedFromGroup: false,
          left: false,

          expireTimer: 0,
          currentNotificationSetting: 'all',
          weAreAdmin: false,
          isPrivate: false,

          avatarPath: '',
          groupAdmins: [],
          lastMessage: undefined,
          members: [],
          priority: CONVERSATION_PRIORITIES.default,
          isPublic: false,
        },
      };
      const comparator = _getConversationComparator(i18n);
      const conversations = _getSortedConversations(data, comparator);

      assert.strictEqual(conversations[0].displayNameInProfile, 'Á');
      assert.strictEqual(conversations[1].displayNameInProfile, 'C');
      assert.strictEqual(conversations[2].displayNameInProfile, 'First!');
      assert.strictEqual(conversations[3].displayNameInProfile, 'B');
    });
  });
});
